@@ -7,7 +7,10 @@ import gobject
 import os, sys
 import tempfile
 import urllib2
-import json
+try:
+	import json
+except ImportError:
+	import simplejson as json
 
 
 #Let's try to use some Google cards
@@ -30,6 +33,7 @@ import sentences.sentences_english as sent
 #import sentences.sentences_german as sent
 
 next_func = None
+location = None
 
 def overlap(a, b):
 	result = [i for i in a  if i in b]
@@ -73,8 +77,8 @@ def parse_input(input):
 	elif exists_in_order(['answer','life','universe','everything'],input.split()) or exists_in_order(['meaning','life','universe','everything'],input.split()):
 		return life_the_universe_and_everything(), None
 
-	elif "weather" in input or "rain" in input or "raining" in input or "rainy" in input or 'sun' in input\
-		or "sunny" in input or "umbrella" in input:
+	elif "weather" in input or "rain" in input or 'sun ' in input\
+		or "sunny" in input or "umbrella" in input or "hot" in input or "cold" in input or "wind" in input:
 		return get_weather(input)
 
 	elif exists_in_order(['chuck', 'norris'], input.split()):
@@ -307,8 +311,23 @@ def get_weather(input):
 	parsed_json = json.loads(json_string)
 	location = parsed_json['location']['city']
 	temp_f = parsed_json['current_observation']['temp_f']
+	feelslike_f = parsed_json['current_observation']['feelslike_f']
+	wind_string = parsed_json['current_observation']['wind_string'].replace("NNW","north-northwest")\
+																	.replace("NNE", "north-northeast")\
+																	.replace("NE", "northeast")\
+																	.replace("ENE", "east-northeast")\
+																	.replace("ESE", "east-southeast")\
+																	.replace("SE", "southeast")\
+																	.replace("SSE", "south-southeast")\
+																	.replace("SSW", "south-southwest")\
+																	.replace("SW", "southwest")\
+																	.replace("WSW", "west-southwest")\
+																	.replace("WNW", "west-northwest")\
+																	.replace("NW", "northwest")\
+																	.replace("MPH", "miles per hour")
 	precip = float(parsed_json['current_observation']['precip_1hr_in'])
 	weather = parsed_json['current_observation']['weather']
+	f.close()
 	if overlap(['rain', 'rainy', 'raining'], input):
 		if precip>0.2 or 'rain' in weather.lower() or ('storm' in weather.lower() and not 'snow' in weather.lower()):
 			return 'Yes.', None
@@ -319,8 +338,23 @@ def get_weather(input):
 			return 'Yes.', None
 		else:
 			return 'No, the current weather in %s is %s.' % (location, weather), None
-	f.close()
-	return "Current temperature in %s is %s degrees." % (location, temp_f), None
+	elif overlap(['hot', 'cold'], input):
+		if abs(float(temp_f)-float(feelslike_f))>2:
+			return "In %s it is %s degrees Fahrenheit, but it feels like %s." % (location, temp_f, feelslike_f), None
+		else:
+			return "It is %s degrees in %s." % (temp_f, location), None
+	elif "umbrella" in input:
+		if 'rain' in weather.lower() or ('storm' in weather.lower() and not 'snow' in weather.lower()):
+			return 'Yes, the weather is %s in %s.' % (weather, location), None
+		elif overlap(['snow', 'flurries', 'blizzard'], weather.lower()):
+			return 'That depends; the weather in %s is %s. Do you use an umbrella in the snow?' % (location, weather), None
+		elif precip>0.2:
+			return 'Maybe; there should be rain but the weather is %s.' % (weather), None
+		else:
+			return "I don't think you need an umbrella; the weather in %s is %s." % (location, weather), None
+	elif "wind" in input:
+		return "The wind in %s is %s." % (location, wind_string.lower()), None
+	return "The weather in %s is %s degrees and %s." % (location, temp_f, weather), None
 
 def settings(input):
 	return "Ok."
